@@ -1,15 +1,23 @@
 from ..constants import *
 from ..abstract import Entry
+from ....logger import Future
 
 from abc import ABC
+import json
 
-
-class Metadata(Entry, ABC):
+class Metadata(Entry, Future, ABC):
     def __init__(self, sk, gk, meta):
-        super().__init__(sk, gk)
+        Entry.__init__(self, sk, gk)
         self.meta = meta
 
     def jsonify(self):
         d = super().jsonify()
         d[METADATA] = self.meta
         return d
+
+    def promise(self):
+        ...
+
+    def fulfill(self):
+        return json.dumps(self.jsonify()) 
+
